@@ -6,7 +6,13 @@ import inspect
 import os
 import shutil
 import warnings
-
+from distributed import Client, LocalCluster
+try:
+    clust = LocalCluster(name='ANAI-Cluster', n_workers=2, threads_per_worker=2, processes=True,
+                        host='0.0.0.0', protocol='tcp://', scheduler_port=0, dashboard_address=0)
+    client = Client(clust)
+except Exception as e:
+    pass
 import modin.pandas as pd
 from colorama import Fore
 from optuna.samplers._tpe.sampler import TPESampler
@@ -16,7 +22,6 @@ from anai.supervised import Classification, Regression
 from anai.utils.connectors import load_data_from_config
 from anai.utils.connectors.data_handler import __df_loader_single, df_loader
 
-os.environ["MODIN_ENGINE"] = "dask"
 
 
 if os.path.exists(os.getcwd() + "/dask-worker-space"):
@@ -30,6 +35,7 @@ def run(
     df=None,
     target: str = None,
     filepath: str = None,
+    df_kwargs: dict = {},
     config: bool = False,
     except_columns: list = [],
     predictor: list = [],
@@ -64,6 +70,10 @@ def run(
                 DataFrame to be used for modelling.
             target : str
                 Target Column Name 
+            filepath : str
+                Filepath of the dataframe to be loaded.
+            df_kwargs : dict
+                Keyword arguments for the dataframe loading function. Only used if filepath is not None.
             except_columns : list, optional
                 List of Columns to be excluded from the dataset
             predictor : list
@@ -137,6 +147,7 @@ def run(
             
             ai = anai.run(
                         filepath='examples/Folds5x2_pp.xlsx', 
+                        df_kwargs={'sheet_name': 'Sheet1'},
                         target='PE',
                         predictor=['lin'],
             )
@@ -149,7 +160,7 @@ def run(
         if not suppress_task_detection:
             print(
                 Fore.YELLOW
-                + "ANAITaskWarning: Task is getting detected automatically. To suppress this behaviour, set suppress_task_detection=True and specify task with task argument",
+                + "ANAITaskWarning: Task is getting detected automatically. To suppress this behaviour, set suppress_task_detection=True and specify task with task=<regression or classification> argument",
                 Fore.RESET,
             )
         else:
@@ -166,7 +177,7 @@ def run(
                 raise FileNotFoundError("ANAI Config File Not Found")
         if df is None:
             if filepath is not None:
-                df = df_loader(filepath, suppress=True)
+                df = df_loader(filepath, suppress=True, **df_kwargs)
             else:
                 raise ValueError("Please provide a dataframe or a filepath")
         if __task(df, target) and not suppress_task_detection or task == "regression":
@@ -182,6 +193,7 @@ def run(
                 df=df,
                 target=target,
                 filepath=filepath,
+                df_kwargs=df_kwargs,
                 config=config,
                 except_columns=except_columns,
                 predictor=predictor,
@@ -206,6 +218,7 @@ def run(
                 metric=metric,
                 ensemble=ensemble,
             )
+            regressor.fit()
             return regressor
         elif (
             not __task(df, target)
@@ -224,6 +237,7 @@ def run(
                 df=df,
                 target=target,
                 filepath=filepath,
+                df_kwargs=df_kwargs,
                 config=config,
                 except_columns=except_columns,
                 predictor=predictor,
@@ -243,6 +257,7 @@ def run(
                 ensemble=ensemble,
                 exclude_models=exclude_models,
             )
+            classifier.fit()
             return classifier
     except KeyboardInterrupt:
         if os.path.exists(os.getcwd() + "/dask-worker-space"):
@@ -283,11 +298,15 @@ def __task(df, target):
         return False
 
 
-def load(df_filepath):
+def load(df_filepath, legacy =False, **df_kwargs):
     """Loads a dataframe from a filepath.
 
     Args:
         df_filepath (str): Filepath of the dataframe to be loaded.
+        legacy (bool, optional): If True, loads the dataframe using pandas.read_csv. 
+            If False, loads the dataframe using modin.pandas.read_csv. 
+            Defaults to False.
+        df_kwargs (dict): Keyword arguments to be passed to df_loader function.
 
     Returns:
         pd.DataFrame : Loaded dataframe.
@@ -296,12 +315,13 @@ def load(df_filepath):
     
     suppress = False
     if type(df_filepath) is str:
-        df = __df_loader_single(df_filepath, suppress=False)
+        df = __df_loader_single(df_filepath, suppress=False, legacy = legacy, **df_kwargs)
     elif type(df_filepath) is list:
         print(Fore.YELLOW + "Loading Data [*]\n")
         df = pd.concat(
             [
-                __df_loader_single(df_filepath[i], suppress=True)
+                __df_loader_single(
+                    df_filepath[i], suppress=True, legacy=legacy, **df_kwargs)
                 for i in range(len(df_filepath))
             ]
         )
